@@ -784,6 +784,25 @@ namespace Task
 		class result{
 		public:
 			result() = default ;
+			result( int exit_code ) :
+				m_finished( true ),
+				m_exitCode( exit_code ),
+				m_exitStatus( 0 )
+			{
+			}
+			template< typename E,typename F >
+			result( E&& std_out,
+				F&& std_error,
+				int exit_code,
+				int exit_status,
+				bool finished ) :
+				m_stdOut( std::forward<E>( std_out ) ),
+				m_stdError( std::forward<F>( std_error ) ),
+				m_finished( finished ),
+				m_exitCode( exit_code ),
+				m_exitStatus( exit_status )
+			{
+			}
 			result( QProcess& e,int s )
 			{
 				m_finished   = e.waitForFinished( s ) ;
@@ -792,11 +811,11 @@ namespace Task
 				m_exitCode   = e.exitCode() ;
 				m_exitStatus = e.exitStatus() ;
 			}
-			QByteArray std_out() const
+			const QByteArray& std_out() const
 			{
 				return m_stdOut ;
 			}
-			QByteArray std_error() const
+			const QByteArray& std_error() const
 			{
 				return m_stdError ;
 			}
@@ -825,7 +844,6 @@ namespace Task
 		private:
 			QByteArray m_stdOut ;
 			QByteArray m_stdError ;
-			bool m_success = false ;
 			bool m_finished = false ;
 			int m_exitCode = 255 ;
 			int m_exitStatus = 255 ;
@@ -880,6 +898,13 @@ namespace Task
 		{
 			return Task::process::run( cmd,{},-1,password ) ;
 		}
+
+		static inline Task::future< result >& run( const QString& cmd,
+							   const QStringList& args,
+							   const QByteArray& password )
+		{
+			return Task::process::run( cmd,args,-1,password ) ;
+		}
 	}
 }
 
