@@ -133,8 +133,10 @@ namespace siritask
 		cryfs,
 		cryfsMigrateFileSystem,
 		encfs,
+		sshfs,
 		gocryptfs,
 		securefs,
+		failedToLoadWinfsp,
 		ecryptfs,
 		ecryptfsIllegalPath,
 		ecrypfsBadExePermissions,
@@ -145,7 +147,8 @@ namespace siritask
 		ecryptfs_simpleNotFound,
 		unknown,
 		failedToCreateMountPoint,
-		backendFail
+		backendFail,
+		volumeCreatedSuccessfully
 	};
 
 	class cmdStatus
@@ -154,6 +157,9 @@ namespace siritask
 		cmdStatus()
 		{
 		}
+		cmdStatus( siritask::status s,int c ) : m_exitCode( c ),m_status( s )
+		{
+		}
 		template< typename T = QString >
 		cmdStatus( const siritask::cmdStatus& s,const T& e = T() )
 		{
