@@ -237,6 +237,8 @@ namespace utility
 	QString externalPluginExecutable() ;
 	void setExternalPluginExecutable( const QString& ) ;
 
+	QString freeWindowsDriveLetter() ;
+
 	void setWindowsMountPointOptions( QWidget *,QLineEdit *,QPushButton * ) ;
 
 	bool reUseMountPoint( void ) ;
@@ -271,7 +273,7 @@ namespace utility
 
 	QString securefsPath() ;
 	QString winFSPpath() ;
-	int winFSPpollingInterval() ;
+	int pollForUpdatesInterval() ;
 
 	bool autoCheck() ;
 	void autoCheck( bool ) ;
@@ -323,6 +325,11 @@ namespace utility
 	QStringList executableSearchPaths( void ) ;
 	QString executableSearchPaths( const QString& ) ;
 
+	void setWindowsExecutableSearchPath( const QString& ) ;
+	QString windowsExecutableSearchPath() ;
+
+	void logCommandOutPut( const ::Task::process::result&,const QString& ) ;
+
 	void polkitFailedWarning( std::function< void() > ) ;
 	bool useSiriPolkit( void ) ;
 	void quitHelper() ;
@@ -518,6 +525,14 @@ namespace utility
 		Task()
 		{
 		}
+		Task( const ::Task::process::result& e )
+		{
+			m_stdError = e.std_error() ;
+			m_stdOut   = e.std_out() ;
+			m_exitCode = e.exit_code() ;
+			m_exitStatus = e.exit_status() ;
+			m_finished = e.finished() ;
+		}
 		Task( const QString& exe,int waitTime = -1,const QProcessEnvironment& env = utility::systemEnvironment(),
 		      const QByteArray& password = QByteArray(),std::function< void() > f = [](){},bool e = false )
 		{
